@@ -7,6 +7,7 @@ from mkapi.core.base import Base, Type
 from mkapi.core.object import (from_object, get_object, get_origin,
                                get_sourcefiles)
 from mkapi.core.structure import Object, Tree
+from mkapi.core import preprocess
 
 
 @dataclass(repr=False)
@@ -37,9 +38,20 @@ class Node(Tree):
                     if not markdown.startswith("Initialize self"):
                         self.docstring = member.docstring
         self.members = [m for m in members if m.object.name != "__init__"]
-        if self.docstring and self.docstring.type:
-            self.object.type = self.docstring.type
-            self.docstring.type = Type()
+
+        doc = self.docstring
+        if doc and 'property' in self.object.kind:
+            if not doc.type and len(doc.sections) == 1 and doc.sections[0].name == "":
+                section = doc.sections[0]
+                markdown = section.markdown
+                type, markdown = preprocess.split_type(markdown)
+                if type:
+                    doc.type = Type(type)
+                    section.markdown = markdown
+
+        if doc and doc.type:
+            self.object.type = doc.type
+            doc.type = Type()
 
     def __iter__(self) -> Iterator[Base]:
         yield from self.object
