@@ -1,16 +1,16 @@
 """This module provides a Page class that works with other converter."""
 import re
 from dataclasses import InitVar, dataclass, field
-from typing import Iterator, List
+from typing import Iterator, List, Union
 
 from mkapi import utils
 from mkapi.core import postprocess
 from mkapi.core.base import Base, Section
-from mkapi.core.inherit import inherit_by_filters
+from mkapi.core.code import Code, get_code
+from mkapi.core.inherit import inherit
 from mkapi.core.linker import resolve_link
 from mkapi.core.node import Node, get_node
 from mkapi.core.regex import MKAPI_PATTERN, NODE_PATTERN, node_markdown
-from mkapi.core.renderer import renderer
 
 
 @dataclass
@@ -31,7 +31,7 @@ class Page:
     abs_src_path: str
     abs_api_paths: List[str] = field(default_factory=list, repr=False)
     markdown: str = field(init=False, repr=False)
-    nodes: List[Node] = field(default_factory=list, init=False, repr=False)
+    nodes: List[Union[Node, Code]] = field(default_factory=list, init=False, repr=False)
 
     def __post_init__(self, source):
         self.markdown = "\n\n".join(self.split(source))
@@ -54,12 +54,18 @@ class Page:
                 if markdown:
                     yield self.resolve_link(markdown)
             heading, name = match.groups()
-            name, filters = utils.filter(name)
-            node = get_node(name)
-            inherit_by_filters(node, filters)
-            postprocess.transform(node, filters)
-            self.nodes.append(node)
-            markdown = node.get_markdown(level=len(heading), callback=callback)
+            level = len(heading)
+            name, filters = utils.split_filters(name)
+            if "code" in filters:
+                code = get_code(name)
+                self.nodes.append(code)
+                markdown = code.get_markdown(level)
+            else:
+                node = get_node(name)
+                inherit(node)
+                postprocess.transform(node, filters)
+                self.nodes.append(node)
+                markdown = node.get_markdown(level, callback=callback)
             yield node_markdown(index, markdown, filters)
             cursor = end
         if cursor < len(source):
@@ -78,6 +84,6 @@ class Page:
             node = self.nodes[int(match.group(1))]
             filters = match.group(2).split("|")
             node.set_html(match.group(3))
-            return renderer.render(node, filters=filters)
+            return node.get_html(filters)
 
         return re.sub(NODE_PATTERN, replace, html)
