@@ -32,13 +32,14 @@ def collect(path: str, docs_dir: str, config_dir) -> Tuple[list, list]:
         logger.error(f"[MkApi] {abs_api_path} exists: Delete manually for safety.")
         sys.exit(1)
     os.mkdir(abs_api_path)
+    os.mkdir(os.path.join(abs_api_path, "source"))
     atexit.register(lambda path=abs_api_path: rmtree(path))
 
     root = os.path.join(config_dir, *paths)
     if root not in sys.path:
         sys.path.insert(0, root)
 
-    package_path, filters = utils.filter(package_path)
+    package_path, filters = utils.split_filters(package_path)
 
     module = get_module(package_path)
     nav = []
@@ -46,12 +47,15 @@ def collect(path: str, docs_dir: str, config_dir) -> Tuple[list, list]:
     modules: Dict[str, str] = {}
     package = None
 
-    def add_page(module: Module) -> str:
+    def add_page(module: Module):
         page_file = module.object.id + ".md"
         abs_path = os.path.join(abs_api_path, page_file)
         abs_api_paths.append(abs_path)
         create_page(abs_path, module, filters)
-        return os.path.join(api_path, page_file)
+        modules[module.object.id] = os.path.join(api_path, page_file)
+
+        abs_path = os.path.join(abs_api_path, "source", page_file)
+        create_source_page(abs_path, module, filters)
 
     for m in module:
         if m.object.kind == "package":
@@ -60,9 +64,9 @@ def collect(path: str, docs_dir: str, config_dir) -> Tuple[list, list]:
             package = m.object.id
             modules = {}
             if m.docstring or any(s.docstring for s in m.members):
-                modules[m.object.id] = add_page(m)
+                add_page(m)
         else:
-            modules[m.object.id] = add_page(m)
+            add_page(m)
     if package and modules:
         nav.append({package: modules})
 
@@ -74,6 +78,12 @@ def create_page(path: str, module: Module, filters: List[str]):
         f.write(module.get_markdown(filters))
 
 
+def create_source_page(path: str, module: Module, filters: List[str]):
+    filters_str = "|".join(filters)
+    with open(path, "w") as f:
+        f.write(f"# ![mkapi]({module.object.id}|code|{filters_str})")
+
+
 def rmtree(path: str):
     if not os.path.exists(path):
         return
